@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 #
-# Copyright (C) 2017 Alexey Kopytov <akopytov@gmail.com>
+# Copyright (C) 2017-2018 Alexey Kopytov <akopytov@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -53,7 +53,6 @@ distros_x86_64=(
     "fedora 27 x86_64"
     "ubuntu trusty x86_64"
     "ubuntu xenial x86_64"
-    "ubuntu zesty x86_64"
     "ubuntu artful x86_64"
     "debian wheezy x86_64"
     "debian jessie x86_64"
@@ -63,7 +62,6 @@ distros_x86_64=(
 distros_i386=(
     "ubuntu trusty i386"
     "ubuntu xenial i386"
-    "ubuntu zesty i386"
     "ubuntu artful i386"
     "debian wheezy i386"
     "debian jessie i386"
