@@ -220,9 +220,7 @@ static void report_intermediate(void)
     silence intermediate reports at the end of the test
   */
   if (ck_pr_load_uint(&sb_globals.report_interval) == 0)
-  {
     return;
-  }
 
   sb_counters_agg_intermediate(cnt);
   report_get_common_stat(&stat, cnt);
@@ -290,20 +288,20 @@ void sb_report_cumulative(sb_stat_t *stat)
   log_text(LOG_NOTICE, "");
 
   log_text(LOG_NOTICE, "Latency (ms):");
-  log_text(LOG_NOTICE, "         min:                            %10.2f",
+  log_text(LOG_NOTICE, "         min: %39.2f",
            SEC2MS(stat->latency_min));
-  log_text(LOG_NOTICE, "         avg:                            %10.2f",
+  log_text(LOG_NOTICE, "         avg: %39.2f",
            SEC2MS(stat->latency_avg));
-  log_text(LOG_NOTICE, "         max:                            %10.2f",
+  log_text(LOG_NOTICE, "         max: %39.2f",
            SEC2MS(stat->latency_max));
 
   if (sb_globals.percentile > 0)
-    log_text(LOG_NOTICE, "        %3dth percentile:                %10.2f",
+    log_text(LOG_NOTICE, "        %3dth percentile: %27.2f",
              sb_globals.percentile, SEC2MS(stat->latency_pct));
   else
     log_text(LOG_NOTICE, "         percentile stats:               disabled");
 
-  log_text(LOG_NOTICE, "         sum:                            %10.2f",
+  log_text(LOG_NOTICE, "         sum: %39.2f",
            SEC2MS(stat->latency_sum));
   log_text(LOG_NOTICE, "");
 
@@ -654,7 +652,7 @@ void print_run_mode(sb_test_t *test)
     log_text(LOG_NOTICE, "Debug mode enabled.\n");
   
   if (sb_globals.validate)
-    log_text(LOG_NOTICE, "Additional request validation enabled.\n");
+    log_text(LOG_NOTICE, "Validation checks: on.\n");
 
   if (sb_rand_seed)
   {
@@ -914,9 +912,9 @@ static void *report_thread_proc(void *arg)
   sb_rand_thread_init();
 
   if (sb_lua_loaded() && sb_lua_report_thread_init())
-  {
     return NULL;
-  }
+
+  pthread_cleanup_push(sb_lua_report_thread_done, NULL);
 
   log_text(LOG_DEBUG, "Reporting thread started");
 
@@ -944,6 +942,8 @@ static void *report_thread_proc(void *arg)
     pause_ns = next_ns - curr_ns;
   }
 
+  pthread_cleanup_pop(1);
+
   return NULL;
 }
 
@@ -963,9 +963,9 @@ static void *checkpoints_thread_proc(void *arg)
   sb_rand_thread_init();
 
   if (sb_lua_loaded() && sb_lua_report_thread_init())
-  {
     return NULL;
-  }
+
+  pthread_cleanup_push(sb_lua_report_thread_done, NULL);
 
   log_text(LOG_DEBUG, "Checkpoints report thread started");
 
@@ -990,8 +990,7 @@ static void *checkpoints_thread_proc(void *arg)
     report_cumulative();
   }
 
-  if (sb_lua_loaded())
-    sb_lua_report_thread_done();
+  pthread_cleanup_pop(1);
 
   return NULL;
 }
@@ -1149,26 +1148,6 @@ static int run_test(sb_test_t *test)
   if (test->ops.cleanup != NULL && test->ops.cleanup() != 0)
     return 1;
 
-  /* print test-specific stats */
-  if (!sb_globals.error)
-  {
-    if (sb_globals.histogram)
-    {
-      log_text(LOG_NOTICE, "Latency histogram (values are in milliseconds)");
-      sb_histogram_print(&sb_latency_histogram);
-      log_text(LOG_NOTICE, " ");
-    }
-
-    report_cumulative();
-  }
-
-  pthread_mutex_destroy(&sb_globals.exec_mutex);
-
-  /* finalize test */
-  if (test->ops.done != NULL)
-    (*(test->ops.done))();
-
-  /* Delay killing the reporting threads to avoid mutex lock leaks */
   if (report_thread_created)
   {
     if (sb_thread_cancel(report_thread) || sb_thread_join(report_thread, NULL))
@@ -1189,6 +1168,25 @@ static int run_test(sb_test_t *test)
       log_errno(LOG_FATAL, "Terminating the checkpoint thread failed.");
   }
 
+  /* print test-specific stats */
+  if (!sb_globals.error)
+  {
+    if (sb_globals.histogram)
+    {
+      log_text(LOG_NOTICE, "Latency histogram (values are in milliseconds)");
+      sb_histogram_print(&sb_latency_histogram);
+      log_text(LOG_NOTICE, " ");
+    }
+
+    report_cumulative();
+  }
+
+  pthread_mutex_destroy(&sb_globals.exec_mutex);
+
+  /* finalize test */
+  if (test->ops.done != NULL)
+    (*(test->ops.done))();
+
   return sb_globals.error != 0;
 }
 
